/*
 *      images.c - this file is part of Geany, a fast and lightweight IDE
 *
 *      Copyright 2005-2007 Enrico Tröger <enrico.troeger@uvena.de>
 *      Copyright 2006-2007 Nick Treleaven <nick.treleaven@btinternet.com>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

/*
 * Inline image data.
 */

/* GdkPixbuf RGBA C-Source image dump */
#include <gtk/gtk.h>

#ifdef __SUNPRO_C
#pragma align 4 (aladin_inline)
#endif
#ifdef __GNUC__
static const guint8 aladin_inline[] __attribute__ ((__aligned__ (4))) =
#else
static const guint8 aladin_inline[] =
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (4096) */
  "\0\0\20\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (128) */
  "\0\0\0\200"
  /* width (32) */
  "\0\0\0\40"
  /* height (32) */
  "\0\0\0\40"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\336\336\336\377\336\336\336\377\275\275\275\377"
  "\275\275\275\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\336\336\336\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\336\336\336\377\336\336\336\377"
  "\336\336\336\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\336\336"
  "\336\377\336\336\336\377\275\275\275\377\0\0\0\0\336\336\336\377\336"
  "\336\336\377\275\275\275\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\336\336\336\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\336\336\336\377\336"
  "\336\336\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\0\0\0\0\336\336\336\377"
  "\336\336\336\377\336\336\336\377\275\275\275\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\336\336\336\377\336\336\336\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377s\204\224\377\0\0\0\0\275\275\275\377\275\275\275"
  "\377\0\0\0\0\0\0\0\0\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377s\204\224"
  "\377\0\0\0\0\275\275\275\377\275\275\275\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\0\0\0\0s\204\224\377\275\275\275\377\275\275"
  "\275\377\275\275\275\377\275\275\275\377s\204\224\377\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\275\275\275\377s\204"
  "\224\377\275\275\275\377s\204\224\377\275\275\275\377s\204\224\377\275"
  "\275\275\377s\204\224\377\275\275\275\377s\204\224\377\275\275\275\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\275\275\275\377s\204\224\377s\204\224\377\0"
  "\0\0\0\0\0\0\0s\204\224\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0s\204\224\377\275"
  "\275\275\377s\204\224\377\275\275\275\377\275\275\275\377\0\0\0\0\0\0"
  "\0\0\275\275\275\377s\204\224\377\275\275\275\377s\204\224\377\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0s\204\224\377\275\275\275\377s\204\224\377\275\275"
  "\275\377s\204\224\377s\204\224\377\0\0\0\0\0\0\0\0\0\0\0\0s\204\224\377"
  "s\204\224\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377"
  "\326\0\377\377\326\0\377\377\245\0\377\0\0\0\0\0\0\0\0s\204\224\377s"
  "\204\224\377s\204\224\377\275\275\275\377s\204\224\377\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377"
  "\0\0\0\0s\204\224\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377"
  "\0\0\0\0\0\0\0\0\377\377\0\377\377\377\0\377\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377"
  "\377\0\377\377\326\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\377\377\0\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377"
  "\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0"
  "\0\0\0\0\0\0\0\377\377\0\377\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377"
  "\377\326\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\326\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377"
  "\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\0\377\377\377\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\245\0\377\0\0\0\0\0\0\0\0\377\326\0\377\377"
  "\245\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0"
  "\377\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377\377"
  "\326\0\377\377\0\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377"
  "\326\0\377\265!!\377\377\326\0\377\377\326\0\377\377\326\0\377\265!!"
  "\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\0\377\377\326\0\377\377\326\0\377\0\0\0\0\0\0\0\0\377\0\0\377\377\326"
  "\0\377\377\0\0\377\377\0\0\377\265!!\377\377\326\0\377\377\326\0\377"
  "\377\0\0\377\377\0\0\377\265!!\377\377\326\0\377\377\0\0\377\265!!\377"
  "\265!!\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\0\377\377\326\0\377\377\326\0\377\0\0\0\0\377\0\0\377\377\326\0\377"
  "\377\0\0\377\377\0\0\377\265!!\377\377\326\0\377\377\326\0\377\377\0"
  "\0\377\377\0\0\377\265!!\377\377\326\0\377\377\0\0\377\265!!\377\265"
  "!!\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\0\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\265!!\377\377\326\0\377\377\326\0\377\377\326\0"
  "\377\265!!\377\377\326\0\377\377\245\0\377\377\245\0\377\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377\377\326\0\377\377\326\0"
  "\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377\245"
  "\0\377\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\377\377\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0"
  "\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\245"
  "\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\377\326\0"
  "\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377\377\326\0\377\377"
  "\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377"
  "\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377"
  "\245\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377\377\377\0\377"
  "\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\326\0\377"
  "\377\326\0\377\377\326\0\377\377\245\0\377\377\245\0\377\377\245\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377\377\377"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377\245"
  "\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\377\326\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\0\377\377\377\0\377\377\326\0\377\377\245\0\377\377\245\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\326\0\377\377\326\0\377\377\326\0\377"
  "\377\326\0\377\377\326\0\377\377\245\0\377\377\245\0\377\377\245\0\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\326\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377\326\0\377\377"
  "\377\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377"
  "\245\0\377\377\245\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\326"
  "\0\377\377\326\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377\245"
  "\0\377\377\326\0\377\377\377\0\377\377\377\0\377\377\326\0\377\377\326"
  "\0\377\377\326\0\377\377\326\0\377\377\245\0\377\377\245\0\377\377\245"
  "\0\377\377\245\0\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};


/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (close_small_inline)
#endif
#ifdef __GNUC__
static const guint8 close_small_inline[] __attribute__ ((__aligned__ (4))) =
#else
static const guint8 close_small_inline[] =
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (171) */
  "\0\0\0\303"
  /* pixdata_type (0x2010002) */
  "\2\1\0\2"
  /* rowstride (40) */
  "\0\0\0("
  /* width (10) */
  "\0\0\0\12"
  /* height (10) */
  "\0\0\0\12"
  /* pixel_data: */
  "\2\0\0\0\10\0\0\0\35\206\0\0\0\0\202\0\0\0\15\1\0\0\0\1\202\0\0\0\377"
  "\204\0\0\0\0\202\0\0\0\377\2\0\0\0\31\0\0\0\0\203\0\0\0\377\202\0\0\0"
  "\0\203\0\0\0\377\203\0\0\0\0\206\0\0\0\377\205\0\0\0\0\204\0\0\0\377"
  "\206\0\0\0\0\204\0\0\0\377\205\0\0\0\0\206\0\0\0\377\203\0\0\0\0\203"
  "\0\0\0\377\202\0\0\0\0\203\0\0\0\377\2\0\0\0\0\0\0\0\13\202\0\0\0\377"
  "\204\0\0\0\0\202\0\0\0\377\202\0\0\0\22\1\0\0\0\11\206\0\0\0\0\2\0\0"
  "\0\21\0\0\0\40"};

/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (newfile_inline)
#endif
#ifdef __GNUC__
static const guint8 newfile_inline[] __attribute__ ((__aligned__ (4))) =
#else
static const guint8 newfile_inline[] =
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0Y\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377"
  "\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\202"
  "\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\377\323\323\323\377\366\366\366\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\371\371\371\377\332\332"
  "\332\377XXX\377\0\0\0\301\0\0\0\6\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\366\366\366\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\307\307\307\377\321\321\321\377\326\326\326\377\0\0\0\377\0"
  "\0\0\10\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\377"
  "\377\377\377\376\376\376\377\375\375\375\377\300\300\300\377\341\341"
  "\341\377\360\360\360\377\233\233\233\377\0\0\0\377\0\0\0\11\0\0\0\1\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\375\375\375\377\374\374\373\377\375\375\375\377\374\374\373"
  "\377\373\373\373\377\257\257\256\377\351\351\351\377\377\377\377\377"
  "\337\337\337\377\217\217\217\377\0\0\0\377\0\0\0\11\0\0\0\1\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\376\376\376\377\375\375\375\377\374\374\373\377\373\373"
  "\373\377\372\372\371\377\373\373\373\377\372\372\371\377\371\371\370"
  "\377\244\244\243\377\360\360\360\377\377\377\377\377\364\364\364\377"
  "\317\317\317\377\242\242\242\377\0\0\0\264\0\0\0\10\0\0\0\1\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\376\376\376\377\375\375\375"
  "\377\374\374\373\377\373\373\373\377\372\372\371\377\371\371\370\377"
  "\370\370\367\377\371\371\370\377\370\370\367\377\370\367\366\377\236"
  "\236\236\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0"
  "\377\0\0\0\201\0\0\0\5\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377"
  "\377\374\374\373\377\373\373\373\377\372\372\371\377\371\371\370\377"
  "\370\370\367\377\370\367\366\377\367\366\365\377\370\367\366\377\367"
  "\366\365\377\366\366\364\377\364\363\362\377\336\335\334\377\323\322"
  "\320\377\267\267\265\377\237\236\235\377poo\377ebZ\377\0\0\0\377\0\0"
  "\0\20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\372\372\371\377"
  "\371\371\370\377\370\370\367\377\370\367\366\377\367\366\365\377\366"
  "\366\364\377\365\364\363\377\366\366\364\377\365\364\363\377\364\363"
  "\362\377\362\362\360\377\344\344\342\377\332\331\327\377\330\330\326"
  "\377\315\314\312\377\257\256\254\377\210\204{\377\0\0\0\377\0\0\0\35"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\370\370\367\377\370"
  "\367\366\377\367\366\365\377\366\366\364\377\365\364\363\377\364\363"
  "\362\377\363\363\361\377\364\363\362\377\363\363\361\377\362\362\360"
  "\377\357\357\355\377\356\355\353\377\355\354\352\377\351\350\346\377"
  "\325\324\323\377\304\303\302\377\217\212\201\377\0\0\0\377\0\0\0\40\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\366\365\364\377\365"
  "\365\363\377\364\363\362\377\364\363\362\377\363\363\361\377\362\362"
  "\360\377\361\361\357\377\362\362\360\377\361\361\357\377\361\360\356"
  "\377\356\355\353\377\354\353\351\377\352\351\347\377\345\344\342\377"
  "\344\343\340\377\322\321\316\377\215\210~\377\0\0\0\377\0\0\0\40\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\364\363\362\377\363\362"
  "\361\377\362\362\360\377\360\360\356\377\357\357\355\377\361\360\356"
  "\377\360\357\355\377\361\360\356\377\360\357\355\377\357\356\354\377"
  "\354\353\351\377\350\347\345\377\345\344\341\377\344\343\340\377\342"
  "\341\336\377\341\337\334\377\227\222\210\377\0\0\0\377\0\0\0\40\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\364\363\362\377\363\362"
  "\361\377\362\362\360\377\360\360\356\377\357\357\355\377\361\360\356"
  "\377\360\357\355\377\361\360\356\377\360\357\355\377\357\356\354\377"
  "\354\353\351\377\350\347\345\377\345\344\341\377\344\343\340\377\342"
  "\341\336\377\341\337\334\377\244\236\223\377\0\0\0\377\0\0\0\40\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\360\360\356\377\357\357"
  "\355\377\357\357\355\377\357\356\354\377\356\355\353\377\355\354\352"
  "\377\355\354\352\377\355\354\352\377\355\354\352\377\354\353\351\377"
  "\350\347\344\377\347\346\343\377\343\342\337\377\342\340\335\377\341"
  "\340\334\377\340\337\333\377\241\234\220\377\0\0\0\377\0\0\0\40\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\355\355\353\377\355\354"
  "\352\377\354\353\351\377\354\353\351\377\354\353\351\377\353\352\350"
  "\377\351\350\345\377\353\352\350\377\351\350\345\377\351\350\345\377"
  "\345\344\341\377\346\344\341\377\343\342\336\377\337\336\332\377\336"
  "\335\331\377\335\334\330\377\241\233\220\377\0\0\0\377\0\0\0\40\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377\377\353\352\350\377\351\350"
  "\346\377\351\350\346\377\350\347\345\377\350\347\344\377\350\347\344"
  "\377\347\346\343\377\350\347\344\377\0\0\0\377\3\3\3\377\0\0\0\377\14"
  "\14\13\377\0\0\0\377\14\14\13\377\0\0\0\377\334\333\327\377\241\233\220"
  "\377\0\0\0\377\0\0\0\40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\377\377\377"
  "\377\347\346\343\377\346\345\342\377\346\345\342\377\346\345\342\377"
  "\345\344\341\377\346\344\341\377\345\344\340\377\346\344\341\377\345"
  "\344\340\377\20\20\20\377\0\0\0\377\0\0\0\377\0\0\0\377\30\30\27\377"
  "\333\331\325\377\331\327\323\377\237\231\215\377\0\0\0\377\0\0\0\40\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\371\371\371\377\344\343\340\377\343"
  "\342\337\377\343\342\336\377\344\342\337\377\344\343\337\377\342\341"
  "\335\377\343\342\336\377\342\341\335\377\343\342\336\377\341\340\334"
  "\377\21\20\20\377\0\0\0\377\17\17\17\377\331\327\323\377\331\327\323"
  "\377\330\326\322\377\236\230\215\377\0\0\0\377\0\0\0\40\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\377\355\355\355\377\341\340\335\377\341\337\334\377"
  "\341\340\334\377\340\337\333\377\342\341\335\377\340\337\333\377\341"
  "\340\334\377\340\337\333\377\341\340\334\377\337\336\332\377\340\336"
  "\332\377\11\11\11\377\334\332\326\377\331\327\323\377\330\326\321\377"
  "\327\325\321\377\235\227\213\377\0\0\0\377\0\0\0\40\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\321\321\321\377\341\337\333\377\340\336\332\377\337"
  "\336\332\377\336\335\331\377\340\337\333\377\336\335\331\377\340\336"
  "\332\377\336\335\331\377\340\336\332\377\336\334\330\377\336\334\330"
  "\377\334\332\326\377\334\332\326\377\330\326\322\377\327\326\321\377"
  "\325\323\316\377\233\225\212\377\0\0\0\377\0\0\0\40\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\377\231\230\221\377\243\236\222\377\244\236\223\377\243"
  "\235\222\377\243\235\221\377\243\235\222\377\241\234\220\377\242\234"
  "\220\377\241\234\220\377\242\234\220\377\241\233\217\377\241\233\220"
  "\377\237\231\215\377\237\231\215\377\235\227\214\377\235\227\214\377"
  "\233\226\212\377gcY\377\0\0\0\377\0\0\0\40\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0]\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
  "\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0"
  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0q\0\0\0\30\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\2\0\0\0\17\0\0\0\35\0\0\0\37\0\0\0\40\0\0"
  "\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40"
  "\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\40\0\0\0\30\0\0\0"
  "\10\0\0\0\0"};

/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (save_all_inline)
#endif
#ifdef __GNUC__
static const guint8 save_all_inline[] __attribute__ ((__aligned__ (4))) =
#else
static const guint8 save_all_inline[] =
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (2304) */
  "\0\0\11\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (96) */
  "\0\0\0`"
  /* width (24) */
  "\0\0\0\30"
  /* height (24) */
  "\0\0\0\30"
  /* pixel_data: */
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\10\11\12\202\33\36\""
  "\377\25\30\32\377\33\27\27\377\"\34\33\377\"\34\33\377\"\33\31\377\""
  "\33\32\377\"\33\32\377\"\33\31\377!\32\31\377!\32\31\377!\32\31\377!"
  "\33\32\377\32\27\26\377\26\30\32\377\30\34\37\377\6\7\10\205\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\34\37\"\377\267\321\353\377"
  "\213\237\260\377\266\227\223\377\354\264\250\377\354\262\246\377\351"
  "\252\236\377\351\254\241\377\347\255\242\377\344\251\236\377\342\245"
  "\232\377\342\243\230\377\341\244\232\377\336\243\232\377\255\215\214"
  "\377\216\235\254\377\223\257\306\377\24\30\33\377\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\33\37!\377\254\311\336\377y\212\236\377"
  "\245xu\377\327\202t\377\327~p\377\325{m\377\325~p\377\320ym\377\316z"
  "n\377\313rg\377\315ui\377\310ma\377\302f\\\377\230fe\377w\206\227\377"
  "c~\224\377\14\20\23\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\32\36!\377\252\310\335\377}\220\240\377\264\242\242\377\350\307\304"
  "\377\351\306\303\377\351\306\303\377\351\307\303\377\347\304\300\377"
  "\347\303\300\377\346\301\275\377\350\306\302\377\345\275\271\377\344"
  "\276\272\377\260\235\236\377z\212\231\377`|\222\377\14\20\23\377\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\32\36!\377\252\306\334\377"
  "~\220\237\377\303\303\303\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\303\303\303\377"
  "|\215\232\377^y\216\377\13\17\22\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\32\36!\377\252\305\333\377}\217\236\377\253\253\253"
  "\377\324\324\324\377\324\324\324\377\324\324\324\377\324\324\324\377"
  "\324\324\324\377\324\324\324\377\324\324\324\377\324\324\324\377\324"
  "\324\324\377\321\321\321\377\244\244\244\377\177\217\234\377[u\212\377"
  "\12\16\21\377\10\11\12\202\33\36\"\377\25\30\32\377\33\27\27\377\"\34"
  "\33\377\"\34\33\377\"\33\31\377\"\33\32\377\"\33\32\377\"\33\31\377!"
  "\32\31\377!\32\31\377!\32\31\377!\33\32\377\32\27\26\377\26\30\32\377"
  "\30\34\37\377}}~\377\377\377\377\377\377\377\377\377\303\303\303\377"
  "\177\217\234\377Yr\205\377\12\15\20\377\34\37\"\377\267\321\353\377\213"
  "\237\260\377\266\227\223\377\354\264\250\377\354\262\246\377\351\252"
  "\236\377\351\254\241\377\347\255\242\377\344\251\236\377\342\245\232"
  "\377\342\243\230\377\341\244\232\377\336\243\232\377\255\215\214\377"
  "\216\235\254\377\223\257\306\377\24\30\33\377\361\361\361\377\360\360"
  "\360\377\272\272\272\377~\216\234\377[q\202\377\12\15\17\377\33\37!\377"
  "\254\311\336\377y\212\236\377\245xu\377\327\202t\377\327~p\377\325{m"
  "\377\325~p\377\320ym\377\316zn\377\313rg\377\315ui\377\310ma\377\302"
  "f\\\377\230fe\377w\206\227\377c~\224\377\14\20\23\377\342\342\342\377"
  "\341\341\341\377\260\260\260\377}\216\233\377ar~\377\14\15\17\377\32"
  "\36!\377\252\310\335\377}\220\240\377\264\242\242\377\350\307\304\377"
  "\351\306\303\377\351\306\303\377\351\307\303\377\347\304\300\377\347"
  "\303\300\377\346\301\275\377\350\306\302\377\345\275\271\377\344\276"
  "\272\377\260\235\236\377z\212\231\377`|\222\377\14\20\23\377\257\257"
  "\257\377\255\255\255\377\221\223\225\377|\216\235\377Vky\377\12\14\16"
  "\377\32\36!\377\252\306\334\377~\220\237\377\303\303\303\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\303\303\303\377|\215\232\377^y\216\377\13\17\22\377"
  "\201\225\245\377\177\223\244\377\200\225\246\377\204\235\262\377Nev\377"
  "\10\13\15\377\32\36!\377\252\305\333\377}\217\236\377\253\253\253\377"
  "\324\324\324\377\324\324\324\377\324\324\324\377\324\324\324\377\324"
  "\324\324\377\324\324\324\377\324\324\324\377\324\324\324\377\324\324"
  "\324\377\321\321\321\377\244\244\244\377\177\217\234\377[u\212\377\12"
  "\16\21\377Wdo\377EZh\377[o\201\377\220\251\300\377Thu\377\10\12\14\377"
  "\32\36!\377\250\303\332\377u\207\226\377\275\275\275\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\303\303\303\377\177\217\234\377Yr\205\377\12\15\20\377\227"
  "\225\217\377Q`k\377Ok\202\377\206\243\272\377Vjv\377\7\12\13\377\32\35"
  "!\377\244\277\330\377z\216\233\377\273\273\273\377\361\361\361\377\361"
  "\361\361\377\361\361\361\377\361\361\361\377\361\361\361\377\361\361"
  "\361\377\361\361\361\377\361\361\361\377\361\361\361\377\360\360\360"
  "\377\272\272\272\377~\216\234\377[q\202\377\12\15\17\377\277\277\274"
  "\377HVb\377Nl\201\377\211\243\266\377Wfs\377\7\11\12\377\31\35!\377\241"
  "\301\327\377z\211\225\377\263\257\257\377\343\343\343\377\342\342\342"
  "\377\342\342\342\377\342\342\342\377\342\342\342\377\342\342\342\377"
  "\342\342\342\377\342\342\342\377\342\342\342\377\341\341\341\377\260"
  "\260\260\377}\216\233\377ar~\377\14\15\17\377\314\314\313\377KYd\377"
  "Nk\177\377\206\241\265\377Wfq\377\7\11\12\377\31\36\40\377\237\301\326"
  "\377{\216\235\377\231\232\235\377\260\260\260\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\255\256\257\377\254\255\255\377\256\256"
  "\256\377\257\257\257\377\257\257\257\377\255\255\255\377\221\223\225"
  "\377|\216\235\377Vky\377\12\14\16\377\320\321\320\377GV_\377Lfx\377}"
  "\234\262\377Vcm\377\10\11\11\377\30\35\40\377\233\273\324\377z\227\257"
  "\377\200\227\252\377\201\225\245\377~\223\244\377{\221\243\377|\221\243"
  "\377z\220\242\377{\220\242\377\200\224\244\377\200\224\244\377\201\225"
  "\245\377\177\223\244\377\200\225\246\377\204\235\262\377Nev\377\10\13"
  "\15\377\262\261\256\377CPZ\377Jat\377z\231\255\377Tbl\377\10\11\11\377"
  "\30\34\40\377\233\267\323\377r\223\255\377s\223\257\377Vhu\377KV_\377"
  "Zgr\377eu\201\377br}\377`oz\377_mw\377^lu\377Wdo\377EZh\377[o\201\377"
  "\220\251\300\377Thu\377\10\12\14\377\30\30\27\377\11\13\15\377\13\16"
  "\20\377%.7\377\26\32\37\377\2\2\2\210\30\35\40\377\231\271\322\377o\220"
  "\250\377Yly\377\207\207\204\377\327\325\321\377\322\320\314\377\325\324"
  "\321\377\335\334\331\377\341\337\334\377\321\317\313\377\307\304\276"
  "\377\227\225\217\377Q`k\377Ok\202\377\206\243\272\377Vjv\377\7\12\13"
  "\377\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\30\35\40\377\230"
  "\270\320\377m\215\245\377Ter\377\260\260\257\377\350\347\343\377db[\377"
  "ROG\377\212\210\202\377\314\312\305\377\302\276\267\377\276\271\262\377"
  "\277\277\274\377HVb\377Nl\201\377\211\243\266\377Wfs\377\7\11\12\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\30\34\40\377\225\266"
  "\317\377m\214\244\377Sco\377\262\263\262\377\354\353\350\377\\YR\377"
  "QNF\377\205\202{\377\305\302\274\377\304\300\272\377\322\317\312\377"
  "\314\314\313\377KYd\377Nk\177\377\206\241\265\377Wfq\377\7\11\12\377"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\24\27\32\377\202\233"
  "\260\377k\211\237\377L[h\377\254\253\252\377\336\335\331\377OLD\377N"
  "JC\377\200|u\377\307\303\275\377\326\323\317\377\346\345\342\377\320"
  "\321\320\377GV_\377Lfx\377}\234\262\377Vcm\377\10\11\11\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\14\15\17\2037AI\377Zo~\377Q`k"
  "\377\224\224\221\377\303\300\272\377\234\227\220\377\250\244\236\377"
  "\271\266\261\377\331\326\322\377\346\345\342\377\343\341\336\377\262"
  "\261\256\377CPZ\377Jat\377z\231\255\377Tbl\377\10\11\11\377\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\3\3\4\26\10\12\13\206\14\16\20"
  "\377\14\16\20\377\24\24\24\377\33\32\31\377\33\32\31\377\35\35\34\377"
  "\36\35\35\377\40\37\37\377!!!\377\40\40\37\377\30\30\27\377\11\13\15"
  "\377\13\16\20\377%.7\377\26\32\37\377\2\2\2\210\0\0\0\0\0\0\0\0\0\0\0"
  "\0\0\0\0\0\0\0\0\0\0\0\0\0"};



